@@ -8,7 +8,7 @@
 //! |Github Repo Secret|CARGO_TOKEN|Token issued for your user by crates.io|[How-To](https://doc.rust-lang.org/cargo/reference/publishing.html#before-your-first-publish)|
 //! |Github Repo Secret|GH_TOKEN|A GitHub PAT|[How-To](https://docs.github.com/en/github/authenticating-to-github/creating-a-personal-access-token)|
 
-#![doc(html_root_url = "https://docs.rs/happi/0.0.2")]
+#![doc(html_root_url = "https://docs.rs/happi-derive/0.0.3")]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 // #![feature(doc_cfg)] // for local docs
 #![warn(missing_copy_implementations)]
@@ -22,4 +22,8 @@ extern crate proc_macro;
 
 /// #[foo]
 #[proc_macro_attribute]
-pub fn foo(attr: proc_macro::TokenStream, item: proc_macro::TokenStream) -> proc_macro::TokenStream {item}
+pub fn foo(attr: proc_macro::TokenStream,
+           item: proc_macro::TokenStream)
+           -> proc_macro::TokenStream {
+  item
+}
